@@ -12,7 +12,9 @@ use Data::Object::Class;
 
 extends 'Zing::PubSub';
 
-our $VERSION = '0.08'; # VERSION
+use Zing::Term;
+
+our $VERSION = '0.09'; # VERSION
 
 # BUILDERS
 
@@ -49,7 +51,7 @@ method size() {
 }
 
 method term() {
-  return $self->next::method('channel');
+  return Zing::Term->new($self)->channel;
 }
 
 1;
