@@ -11,11 +11,13 @@ use routines;
 use Data::Object::Class;
 use Data::Object::ClassHas;
 
+use Carp ();
+
 use Config;
 use File::Spec;
 use POSIX;
 
-our $VERSION = '0.08'; # VERSION
+our $VERSION = '0.09'; # VERSION
 
 # ATTRIBUTES
 
@@ -48,6 +50,7 @@ has 'pid_dir' => (
 );
 
 fun new_pid_dir($self) {
+  -w $ENV{ZING_PIDDIR} ? $ENV{ZING_PIDDIR} :
   -w $ENV{ZING_HOME} ? $ENV{ZING_HOME} :
   -w File::Spec->curdir ? File::Spec->curdir : File::Spec->tmpdir
 }
@@ -114,13 +117,13 @@ method fork() {
   my $app = $self->app;
 
   if ($Config{d_pseudofork}) {
-    die "Error on fork: fork emulation not supported";
+    Carp::confess "Error on fork: fork emulation not supported";
   }
 
   my $pid = fork;
 
   if (!defined $pid) {
-    die "Error on fork: $!";
+    Carp::confess "Error on fork: $!";
   }
   elsif ($pid == 0) {
     $self->app->start; # child
