@@ -15,8 +15,9 @@ extends 'Zing::Watcher';
 
 use Zing::Channel;
 use Zing::Logic::Kernel;
+use Zing::Term;
 
-our $VERSION = '0.08'; # VERSION
+our $VERSION = '0.09'; # VERSION
 
 # ATTRIBUTES
 
@@ -44,6 +45,10 @@ fun new_logic($self) {
 
 # METHODS
 
+method term() {
+  return Zing::Term->new($self)->kernel;
+}
+
 1;
 
 =encoding utf8
