@@ -12,26 +12,26 @@ use Data::Object::Class;
 
 extends 'Zing::Logic';
 
-our $VERSION = '0.08'; # VERSION
+our $VERSION = '0.09'; # VERSION
 
 # METHODS
 
 method flow() {
   my $step_0 = Zing::Flow->new(
     name => 'on_register',
-    code => fun($step, $loop) { $self->on_register->($self) }
+    code => fun($step, $loop) { $self->trace('on_register')->($self) }
   );
   my $step_1 = $step_0->next(Zing::Flow->new(
     name => 'on_perform',
-    code => fun($step, $loop) { $self->on_perform->($self) }
+    code => fun($step, $loop) { $self->trace('on_perform')->($self) }
   ));
   my $step_2 = $step_1->next(Zing::Flow->new(
     name => 'on_reset',
-    code => fun($step, $loop) { $self->on_reset->($self) }
+    code => fun($step, $loop) { $self->trace('on_reset')->($self) }
   ));
   my $step_3 = $step_2->next(Zing::Flow->new(
     name => 'on_suicide',
-    code => fun($step, $loop) { $self->on_suicide->($self) }
+    code => fun($step, $loop) { $self->trace('on_suicide')->($self) }
   ));
 
   $step_0
