@@ -13,7 +13,9 @@ use Data::Object::ClassHas;
 
 extends 'Zing::PubSub';
 
-our $VERSION = '0.08'; # VERSION
+use Zing::Term;
+
+our $VERSION = '0.09'; # VERSION
 
 # ATTRIBUTES
 
@@ -47,7 +49,7 @@ method recv() {
 }
 
 method message(HashRef $val) {
-  +{ data => $val, from => $self->name };
+  return { data => $val, from => $self->term };
 }
 
 method reply(HashRef $bag, HashRef $val) {
@@ -63,7 +65,7 @@ method size() {
 }
 
 method term(Maybe[Str] $name) {
-  return $self->global($name || $self->name, 'mailbox');
+  return Zing::Term->new($name || $self)->mailbox;
 }
 
 1;
@@ -166,7 +168,7 @@ The recv method receives a single new message from the mailbox.
 
   # given: synopsis
 
-  $mailbox->send($mailbox->process->name, { status => 'hello' });
+  $mailbox->send($mailbox->term, { status => 'hello' });
 
   $mailbox->recv;
 
@@ -187,7 +189,7 @@ received and returns the size of the recipient mailbox.
 
   # given: synopsis
 
-  $mailbox->send($mailbox->process->name, { status => 'hello' });
+  $mailbox->send($mailbox->term, { status => 'hello' });
 
   my $data = $mailbox->recv;
 
@@ -210,7 +212,7 @@ size of the recipient mailbox.
 
   # given: synopsis
 
-  $mailbox->send($mailbox->process->name, { status => 'hello' });
+  $mailbox->send($mailbox->term, { status => 'hello' });
 
 =back
 
