@@ -12,10 +12,17 @@ use Data::Object::Class;
 
 extends 'Zing::Repo';
 
-our $VERSION = '0.08'; # VERSION
+use Zing::Poll;
+use Zing::Term;
+
+our $VERSION = '0.09'; # VERSION
 
 # METHODS
 
+method poll(Str $key) {
+  return Zing::Poll->new(repo => $self, name => $key);
+}
+
 method recv(Str $key) {
   return $self->store->pull($self->term($key));
 }
@@ -25,7 +32,7 @@ method send(Str $key, HashRef $val) {
 }
 
 method term(Str @keys) {
-  return $self->next::method('pubsub', @keys);
+  return Zing::Term->new($self, @keys)->pubsub;
 }
 
 1;
@@ -82,6 +89,25 @@ This package implements the following methods:
 
 =cut
 
+=head2 poll
+
+  poll(Str $key) : Poll
+
+The poll method returns a L<Zing::Poll> object which can be used to perform a
+blocking-fetch from the store.
+
+=over 4
+
+=item poll example #1
+
+  # given: synopsis
+
+  $pubsub->poll('priority-1');
+
+=back
+
+=cut
+
 =head2 recv
 
   recv(Str $key) : Maybe[HashRef]
