@@ -13,7 +13,9 @@ use Data::Object::ClassHas;
 
 extends 'Zing::KeyVal';
 
-our $VERSION = '0.08'; # VERSION
+use Zing::Term;
+
+our $VERSION = '0.09'; # VERSION
 
 # ATTRIBUTES
 
@@ -39,7 +41,7 @@ method send(Process $proc) {
 }
 
 method term(Str @keys) {
-  return $self->next::method('registry', @keys);
+  return Zing::Term->new($self, @keys)->registry;
 }
 
 1;
