@@ -13,8 +13,9 @@ use Data::Object::ClassHas;
 
 use Zing::Server;
 use Zing::Store;
+use Zing::Term;
 
-our $VERSION = '0.08'; # VERSION
+our $VERSION = '0.09'; # VERSION
 
 # ATTRIBUTES
 
@@ -60,10 +61,6 @@ method drop(Str @keys) {
   return $self->store->drop($self->term(@keys));
 }
 
-method global (Str @keys) {
-  return join(':', 'zing', @keys);
-}
-
 method ids() {
   return $self->store->keys($self->term);
 }
@@ -72,12 +69,8 @@ method keys() {
   return [map {my $re = quotemeta $self->term; s/^$re://r} @{$self->ids}];
 }
 
-method local(Str @keys) {
-  return join(':', 'zing', $self->server->name, @keys);
-}
-
 method term(Str @keys) {
-  return join(':', $self->${\"@{[$self->target]}"}, $self->name, @keys);
+  return Zing::Term->new($self, @keys)->repo;
 }
 
 method test(Str @keys) {
@@ -186,24 +179,6 @@ The drop method returns truthy if the data was removed from the store.
 
 =cut
 
-=head2 global
-
-  global(Str @keys) : Str
-
-The global method returns a global term (safe word) for the datastore.
-
-=over 4
-
-=item global example #1
-
-  # given: synopsis
-
-  $repo->global('text-1');
-
-=back
-
-=cut
-
 =head2 ids
 
   ids() : ArrayRef[Str]
@@ -226,7 +201,8 @@ The ids method returns a list of IDs (keys) stored under the datastore namespace
 
   keys() : ArrayRef[Str]
 
-The keys method returns a list of fully-qualified keys stored under the datastore namespace.
+The keys method returns a list of fully-qualified keys stored under the
+datastore namespace.
 
 =over 4
 
@@ -240,24 +216,6 @@ The keys method returns a list of fully-qualified keys stored under the datastor
 
 =cut
 
-=head2 local
-
-  local(Str @keys) : Str
-
-The local method returns a local term (safe word) for the datastore which includes the node name.
-
-=over 4
-
-=item local example #1
-
-  # given: synopsis
-
-  $repo->local('text-1');
-
-=back
-
-=cut
-
 =head2 term
 
   term(Str @keys) : Str
