@@ -12,23 +12,16 @@ use Data::Object::Class;
 
 extends 'Zing::Worker';
 
-our $VERSION = '0.08'; # VERSION
+our $VERSION = '0.09'; # VERSION
 
 # METHODS
 
 method handle(Str $name, HashRef $data) {
   return $self if !$data->{scheme};
 
-  $self->spawn($data->{scheme});
+  my $fork = $self->spawn($data->{scheme});
 
-  my $class = $data->{scheme}[0];
-
-  ($self->{launched}{$class} ||= 0)++;
-
-  # due to the unforeseen (but expected) consequences of loading too many
-  # packages into memory, a launcher should kill itself after loading some
-  # arbitrary number of packages
-  $self->winddown if keys %{$self->{launched}} > 50;
+  do {0} while $fork->sanitize;
 
   return $self;
 }
