@@ -13,7 +13,7 @@ use Data::Object::ClassHas;
 
 use JSON -convert_blessed_universally;
 
-our $VERSION = '0.08'; # VERSION
+our $VERSION = '0.09'; # VERSION
 
 # ATTRIBUTES
 
@@ -48,6 +48,11 @@ method keys(Str @keys) {
   return [map $self->redis->keys($self->term(@$_)), [@keys], [@keys, '*']];
 }
 
+method pop(Str $key) {
+  my $get = $self->redis->rpop($key);
+  return $get ? $self->load($get) : $get;
+}
+
 method pull(Str $key) {
   my $get = $self->redis->lpop($key);
   return $get ? $self->load($get) : $get;
@@ -235,6 +240,37 @@ The load method decodes the JSON data provided and returns the data as a hashref
 
 =cut
 
+=head2 pop
+
+  pop(Str $key) : Maybe[HashRef]
+
+The pop method pops data off of the bottom of a list in the datastore.
+
+=over 4
+
+=item pop example #1
+
+  # given: synopsis
+
+  $store->pop('collection');
+
+=back
+
+=over 4
+
+=item pop example #2
+
+  # given: synopsis
+
+  $store->push('collection', { status => 1 });
+  $store->push('collection', { status => 2 });
+
+  $store->pop('collection');
+
+=back
+
+=cut
+
 =head2 pull
 
   pull(Str $key) : Maybe[HashRef]
