@@ -11,7 +11,7 @@ use base 'Data::Object::Types::Library';
 
 extends 'Types::Standard';
 
-our $VERSION = '0.08'; # VERSION
+our $VERSION = '0.09'; # VERSION
 
 register {
   name => 'Channel',
@@ -25,6 +25,12 @@ register {
   validation => is_instance_of('Zing::Data'),
 };
 
+register {
+  name => 'Domain',
+  parent => 'Object',
+  validation => is_instance_of('Zing::Domain'),
+};
+
 register {
   name => 'Error',
   parent => 'Object',
@@ -88,6 +94,12 @@ register {
   validation => is_instance_of('Zing::Node'),
 };
 
+register {
+  name => 'Poll',
+  parent => 'Object',
+  validation => is_instance_of('Zing::Poll'),
+};
+
 register {
   name => 'Process',
   parent => 'Object',
@@ -124,6 +136,9 @@ register {
   validation => is_instance_of('Zing::Repo'),
 };
 
+declare 'Schedule',
+  as Tuple([Str(), ArrayRef([Str()]), HashRef()]);
+
 declare 'Scheme',
   as Tuple([Str(), ArrayRef(), Int()]);
 
@@ -288,6 +303,42 @@ This type is defined in the L<Zing::Types> library.
 
 =cut
 
+=head2 domain
+
+  Domain
+
+This type is defined in the L<Zing::Types> library.
+
+=over 4
+
+=item domain parent
+
+  Object
+
+=back
+
+=over 4
+
+=item domain composition
+
+  InstanceOf["Zing::Domain"]
+
+=back
+
+=over 4
+
+=item domain example #1
+
+  # given: synopsis
+
+  use Zing::Domain;
+
+  my $domain = Zing::Domain->new(name => 'exchange');
+
+=back
+
+=cut
+
 =head2 flow
 
   Flow
@@ -646,6 +697,44 @@ This type is defined in the L<Zing::Types> library.
 
 =cut
 
+=head2 poll
+
+  Poll
+
+This type is defined in the L<Zing::Types> library.
+
+=over 4
+
+=item poll parent
+
+  Object
+
+=back
+
+=over 4
+
+=item poll composition
+
+  InstanceOf["Zing::Poll"]
+
+=back
+
+=over 4
+
+=item poll example #1
+
+  # given: synopsis
+
+  use Zing::Poll;
+  use Zing::KeyVal;
+
+  my $keyval = Zing::KeyVal->new(name => 'notes');
+  my $poll = Zing::Poll->new(name => 'last-week', repo => $keyval);
+
+=back
+
+=cut
+
 =head2 process
 
   Process
@@ -862,6 +951,58 @@ This type is defined in the L<Zing::Types> library.
 
 =cut
 
+=head2 schedule
+
+  Schedule
+
+This type is defined in the L<Zing::Types> library.
+
+=over 4
+
+=item schedule composition
+
+  Tuple[Str, ArrayRef[Str], HashRef]
+
+=back
+
+=over 4
+
+=item schedule example #1
+
+  # given: synopsis
+
+  # at 00:00 on day-of-month 1 in january
+
+  ['0 0 1 1 *', ['task_queue'], { task => 'execute' }];
+
+=back
+
+=over 4
+
+=item schedule example #2
+
+  # given: synopsis
+
+  # at 00:00 on saturday
+
+  ['0 0 * * SAT', ['task_queue'], { task => 'execute' }];
+
+=back
+
+=over 4
+
+=item schedule example #3
+
+  # given: synopsis
+
+  # at minute 0 (hourly)
+
+  ['0 * * * *', ['task_queue'], { task => 'execute' }];
+
+=back
+
+=cut
+
 =head2 scheme
 
   Scheme
