@@ -29,13 +29,21 @@ unless ($ENV{TEST_REDIS}) {
 }
 
 unless ($ENV{TEST_REDIS}) {
-  *{"Zing::Store::pull"} = sub {
+  *{"Zing::Store::pop"} = sub {
     my ($self, $key) = @_;
     my $get = pop @{$DATA->{$key}} if $DATA->{$key};
     return $get ? $self->load($get) : $get;
   };
 }
 
+unless ($ENV{TEST_REDIS}) {
+  *{"Zing::Store::pull"} = sub {
+    my ($self, $key) = @_;
+    my $get = shift @{$DATA->{$key}} if $DATA->{$key};
+    return $get ? $self->load($get) : $get;
+  };
+}
+
 unless ($ENV{TEST_REDIS}) {
   *{"Zing::Store::push"} = sub {
     my ($self, $key, $val) = @_;
@@ -93,6 +101,8 @@ use Zing::Daemon;
 use Zing::Fork;
 use Zing::Logic;
 use Zing::Loop;
+use Zing::Process;
+use Zing::Timer;
 
 use Data::Object::Space;
 
@@ -140,9 +150,6 @@ our $PIDS = $$ + 1;
   my $space = Data::Object::Space->new(
     'Zing/Fork'
   );
-  $space->inject(_kill => sub {
-    $ENV{ZING_TEST_KILL} || 0;
-  });
   $space->inject(_waitpid => sub {
     $ENV{ZING_TEST_WAIT_ONE}
     ? ($ENV{ZING_TEST_WAIT_ONE}++ == 1 ? 1 : -1)
@@ -162,16 +169,6 @@ our $PIDS = $$ + 1;
   });
 }
 
-# Zing/Logic
-{
-  my $space = Data::Object::Space->new(
-    'Zing/Logic'
-  );
-  $space->inject(_kill => sub {
-    $ENV{ZING_TEST_KILL} || 0;
-  });
-}
-
 # Zing/Loop
 {
   my $space = Data::Object::Space->new(
@@ -183,4 +180,28 @@ our $PIDS = $$ + 1;
   });
 }
 
+# Zing/Process
+{
+  my $space = Data::Object::Space->new(
+    'Zing/Process'
+  );
+  $space->inject(_kill => sub {
+    $ENV{ZING_TEST_KILL} || 0;
+  });
+}
+
+# Zing/Timer
+{
+  my $space = Data::Object::Space->new(
+    'Zing/Timer'
+  );
+  $space->inject(_time => sub {
+    $ENV{ZING_TEST_TIME} || time;
+  });
+  $space->inject(execute => sub {
+    my ($self, @args) = @_;
+    $self->exercise(@args); # always run once
+  });
+}
+
 1;
